% DEFMECHMAP - VERSION 11b
% 
% Copyright 2007, J M Warren (jmwarren@alum.mit.edu).
% Updated 2011 to correct 'contour' for Matlab v7 and later.
% 
% DEFMECHMAP is part of OlivineDeformationMaps and calls the subroutine
% OLFLOW.
% 
% OlivineDeformationMaps is free software: you can redistribute it and/or
% modify it under the terms of the GNU General Public License as published
% by the Free Software Foundation, either version 3 of the License, or (at
% your option) any later version.
% 
% OlivineDeformationMaps is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with OlivineDeformationMaps. If not, see <http://www.gnu.org/licenses/>.
% 
% 
% DEFMECHMAP plots olivine deformation mechanism maps. It shows the
% variation of stress as a function of grain size, contoured for strain
% rate, at a given T and P. Flow laws for Dislocation Creep, Diffusion
% Creep and Dislocation-Accommodated Grain Boundary Sliding (DisGBS) are
% from Bai et al. (1991) and Hirth and Kohlstedt (2003). The Low-Temperature
% Plasticity flow law is from Goetze (1978) and Evans & Goetze (1979). Note
% that a kluge is necessary in OLFLOW to limit LTP from appearing on the
% deformation mechanism map at low stress. The olivine piezometer is
% calculated from a linear least squares fit to the data in Karato et al.
% (1980) and Van der Wal et al. (1993).
% 
% Additional subroutines are available from jmwarren@alum.mit.edu to
% calculate (i) the error in GBS and diffusion creep boundaries due to
% uncertainty in activation energy and (ii) the DisGBS field using a
% different grain size exponent for the GBS component.


clear all
T=1250+273;					% Temp in Kelvin
P=4e8;						% Pressure in Pa
depth=P*3/1e8;				% Equivalent depth in km
R=8.314;					% Ideal gas constant (J/K/mol)
sig=10.^(0:.01:4);			% Stress in MPa
gs=10.^(0:.01:4);			% Grain size in microns
[sigma,d]=ndgrid(sig,gs);	% Create grid for stress and for grain size

[dif,dis,ltp,gbsg,gbse]=olflow_v11(sigma,d,T,P,R);	% Calculate strain rate
edot=cat(3,dif,dis,ltp,gbsg,gbse);	% Combine strain rates into 3D matrix
tot=dif+dis+ltp+gbsg+gbse;

% Edot max values & max value index: 1=dif; 2=dis; 3=ltp; 4=gbsg; 5=gbse
[p1,ind1]=max(edot,[],3);

% Colormap for deformation mechanisms, order is dif, dis, ltp, gbsg, gbse
cmap=[0.00    0.50    0.40
      0.50    0.75    0.40
      0.75    0.88    0.40
      1.00    0.65    0.00
      1.00    0.85    0.00];
      
% % Phil Skemer's alternative colormap, order is dif, dis, ltp, gbsg, gbse
% cmap=[0.50    0.40    0.90
%       0.50    0.50    0.80
%       0.50    0.60    0.70
%       0.50    0.70    0.60
%       0.50    0.80    0.50];

% Plot deformation mechanism map
figure(1); clf; plot(1); hold on
set(gca,'xscale','log','yscale','log','Layer','Top')
xlim([min(min(gs)) max(max(gs))])
ylim([min(sig) max(sig)])
contourf(gs,sig,ind1,[0 1 2 3 4 5]);
shading flat; colormap(cmap);
axis square
xlabel('Grain Size, d (\mum)','FontSize',14)
ylabel('Stress, \sigma (MPa)','FontSize',14)
title(['Olivine, Dry, ' num2str(T-273) '^\oC, ' num2str(depth) 'km'],'FontSize',14)

% Deformation mechanism field boundaries
[c1,l1]=contour(gs,sig,ind1,[1.5 2.5 3.5],'w');   % Plot field boundaries (with GBS)
set(l1,'linewidth',2)

% Strain rate contours
edotc=10.^(0:-4:-12);
[c3,l3]=contour(d,sigma,tot,edotc,'-k');
set(l3,'linewidth',1)
hl3=get(l3,'Children');
t1=zeros(length(edotc));
t2=zeros(length(edotc));
for i=1:length(edotc)
    t1(i)=text(2.8e3,1.2*max(get(hl3(i),'ydata')),['{\fontsize{15} \epsilon} = ' num2str(round(log10(get(hl3(i),'UserData'))))]);
    t2(i)=text(2.9e3,1.3*max(get(hl3(i),'ydata')),'\fontsize{15} \cdot');
end

% Piezometer: Karato et al. (1980) and Van der Wal et al. (1993)
% The original data in the next lines was used in a linear least squares
% regression to obtain the values below for the piezometer:
% dk=[193.981 135.123 86.447 118.934 86.447 46.159 45.670 59.580 40.199 39.773 30.488 24.910]';	% Microns
% sk=[25.035 34.719 41.538 49.697 55.225 63.342 72.652 85.106 86.921 102.901 121.820 135.372]';	% MPa
% dvdw=[21 18 14 57 29 8.2 52 28 30 30 17 16 14 18 19 21 17 15]';	% Microns
% svdw=[146 174 212 58 119 284 63 85 88 90 127 146 188 120 132 102 150 266]';	% MPa
m=-1.3370;		% Slope from lsqfitma regression of x on y and y on x
sm=0.0791;		% Standard deviation of the slope
b=4.1755;		% Intercept from lsqfitma regression of x on y and y on x
sb=0.1133;		% Standard deviation of the y-intercept
sfit(:,1)=((log10(gs')-b)./m);				% Log10(Stress) in MPa
sfit(:,2)=((log10(gs')-(b-sb))./(m+sm));	% Error in stress
sfit(:,3)=((log10(gs')-(b+sb))./(m-sm));	% Error in stress
plot(gs',10.^sfit(:,1),'k','linewidth',1);	% Regression line through exp. data
plot(gs',10.^sfit(:,2),'k','linewidth',1);	% Plot error
plot(gs',10.^sfit(:,3),'k','linewidth',1);	% Plot error

print('-dpdf',['DefMap_' num2str(T-273) 'C' num2str(depth) 'km'])
% print('-depsc2',['DefMap_' num2str(T-273) 'C' num2str(depth) 'km'])
% print('-dpdf',['DefMap_' num2str(T-273) 'C' num2str(P/1e6) 'MPa'])

