function [dif,dis,ltp,gbsg,gbse]=olflow_v11(sigma,d,T,P,R)

% Copyright 2007, J M Warren (jmwarren@alum.mit.edu).
% 
% OLFLOW is part of OlivineDeformationMaps and is called by DEFMECHMAP.
% 
% OlivineDeformationMaps is free software: you can redistribute it and/or
% modify it under the terms of the GNU General Public License as published
% by the Free Software Foundation, either version 3 of the License, or (at
% your option) any later version.
% 
% OlivineDeformationMaps is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with OlivineDeformationMaps. If not, see <http://www.gnu.org/licenses/>.
% 
% 
% OLFLOW returns the strain rate for the dry, melt-free olivine flow laws
% given stress (MPa), grain size (micron), temperature (K), and pressure
% (Pa). OLFLOW returns the total strain rate (TOT), as well as the
% individual contributions from dislocation creep (DIS), diffusion creep
% (DIF), and grain boundary sliding (GBS) at the given conditions. Flow
% laws for Dislocation Creep, Diffusion Creep and Dislocation-Accommodated
% Grain Boundary Sliding (DisGBS) are from Bai et al. (1991) and Hirth and
% Kohlstedt (2003). The Low-Temperature Plasticity flow law is from Goetze
% (1978) and Evans & Goetze (1979). Note that LTP is artificially cut off
% at low stress, as this mechanism does not operate at low stress whereas
% the LTP formulation allows it to continue to low stress.


% Dry Diffusion Creep
A=1.5*1e9;      % Pre-exponential factor (sig-MPa, d-um, P-Pa, T-C)
n=1;            % stress exponent
Q=375*1e3;      % Activation energy (50 kJ/mol)
V=6*1e-6;       % Activation volume (4 m3/mol)
p=-3;           % Grain size exponent
dif=A*(sigma.^n).*(d.^p).*exp(-(Q+P*V)./(R*T));

% Dry Dislocation Creep
A=1.1*1e5;      % Pre-exponential factor (MPa, um)
n=3.5;          % stress exponent
Q=530*1e3;      % Activation energy (50 kJ/mol)
V=18*1e-6;      % Activation volume (m3/mol)
p=0;            % Grain size exponent
dis=A*(sigma.^n).*(d.^p).*exp(-(Q+P*V)./(R*T));

% "Low Temperature" Crystal Plasticity
A=5.7*1e11;     % Pre-exponential factor (s^-1)
n=2;            % stress exponent
Q=5.4*1e5;      % Activation energy (J/mol)
sp=8.5*1e3;     % Peierls Stress (MPa)
ltp=A*exp(-Q./(R.*T).*(1-(sigma./sp)).^n);
% a=find(sigma<=200);   % For shallow depths, low temp (12km, 700C)
a=find(sigma<=800);   % For shallow depths, moderate temp (12km, 1250C)
% a=find(sigma<=1000);    % For increasing depths (50km, 1100C)
% a=find(sigma<=10000);    % For deeper depths (1250C, 90km)
ltp(a)=0;

% Dislocation accommodated Grain Boundary Sliding (disGBS)
% GBS component
n=3.5;          % stress exponent
V=18*1e-6;      % Activation volume (2-10 m3/mol)
p2=-2;			% Grain size exponent
A2lT=6500;      % Low temp pre-exponential factor, um2/s/MPa3.5
A2hT=4.7*1e10;	% High temp pre-exponential factor, um2/s/MPa3.5
if T<(1250+273)
	Q=400*1e3;      % Activation energy (50 kJ/mol)
	gbsc=A2lT*(sigma.^n).*(d.^p2).*exp(-(Q+P*V)./(R*T));
elseif T>=(1250+273)
	Q=600*1e3;      % Activation energy (50 kJ/mol)
	gbsc=A2hT*(sigma.^n).*(d.^p2).*exp(-(Q+P*V)./(R*T));
end
% Easy slip system component
A=22.2;         % Pre-exponential factor (MPa, um)
n=3.5;          % stress exponent
Q=400*1e3;      % Activation energy (50 kJ/mol)
V=18*1e-6;      % Activation volume (m3/mol)
p=0;            % Grain size exponent
essc=A*(sigma.^n).*(d.^p).*exp(-(Q+P*V)./(R*T));

% Combined disGBS
[k l]=size(gbsc);
gbsg=zeros([k l]);
gbse=zeros([k l]);
% gbsg=1./(1./gbsc); gbse=zeros([k l]);     % GBS component only
% gbse=1./(1./essc); gbsg=zeros([k l]);     % ESS component only
for i=1:k
	for j=1:l
		if gbsc(i,j)<=essc(i,j)
			gbsg(i,j)=(1./gbsc(i,j)+1./essc(i,j)).^-1;	% Region where GBS is the rate limiting component
			gbse(i,j)=0;
		else
			gbsg(i,j)=0;
			gbse(i,j)=(1./gbsc(i,j)+1./essc(i,j)).^-1;	% Region where Easy Slip is the rate limiting component
		end;
	end
end
